aind\_behavior\_curriculum.curriculum
=====================================

.. automodule:: aind_behavior_curriculum.curriculum
  
   
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
      :toctree:
   
      create_curriculum
      is_non_deserializable_callable
      make_task_discriminator
      try_materialize_non_deserializable_callable_error
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
      :toctree:
      :template: custom-class-template.rst               
   
      Curriculum
      Metrics
      MetricsProvider
      Policy
      PolicyGraph
      PolicyTransition
      Stage
      StageGraph
      StageTransition
   
   

   
   
   



